@@ -1196,20 +1196,20 @@ class Class:
     #
     def audit(self, event, detector, priority = 100):
         """Register an auditor detector"""
-        self.auditors[event].append((priority, detector))
+        self.auditors[event].append((priority, detector.__name__, detector))
 
     def fireAuditors(self, event, nodeid, newvalues):
         """Fire all registered auditors"""
-        for prio, audit in self.auditors[event]:
+        for prio, name, audit in self.auditors[event]:
             audit(self.db, self, nodeid, newvalues)
 
     def react(self, event, detector, priority = 100):
         """Register a reactor detector"""
-        self.reactors[event].append((priority, detector))
+        self.reactors[event].append((priority, detector.__name__, detector))
 
     def fireReactors(self, event, nodeid, oldvalues):
         """Fire all registered reactors"""
-        for prio, react in self.reactors[event]:
+        for prio, name, react in self.reactors[event]:
             react(self.db, self, nodeid, oldvalues)
 
     #
