@@ -282,6 +282,12 @@ class RoundupRequestHandler(BaseHTTPServer.BaseHTTPRequestHandler):
             # stderr is no longer viable
             pass
 
+    def start_response(self, headers, response):
+        self.send_response(response)
+        for key, value in headers:
+            self.send_header(key, value)
+        self.end_headers()
+
 def error():
     exc_type, exc_value = sys.exc_info()[:2]
     return _('Error: %s: %s' % (exc_type, exc_value))
@@ -324,6 +330,7 @@ def setuid(user):
 
     if os.getuid():
         print _('WARNING: ignoring "-u" argument, not root')
+        return
 
     try:
         import pwd
